sturdy.throttle


wrap-ip-rate-limitclj

(wrap-ip-rate-limit handler limiter extract-ip)

Ring middleware that uses an in-memory IP rate limiter. Blocks offenders with a minimal 429 response to save bandwidth.

Ring middleware that uses an in-memory IP rate limiter.
Blocks offenders with a minimal 429 response to save bandwidth.
sourceraw docstring

wrap-quota-rate-limitclj

(wrap-quota-rate-limit handler limiter extract-key error-response)

Ring middleware that uses the SQLite quota limiter. Provides a more helpful error message when the quota is exceeded.

Ring middleware that uses the SQLite quota limiter.
Provides a more helpful error message when the quota is exceeded.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries