Clojure only.

sturdy.throttle.core


RateLimitercljprotocol

admit?clj

(admit? this key)

Returns true if the key is allowed under the rate limit, false otherwise.

Returns true if the key is allowed under the rate limit, false otherwise.
source

cljdoc builds & hosts documentation for Clojure/Script libraries