(admit? this key)Returns true if the key is allowed under the rate limit, false otherwise.
Returns true if the key is allowed under the rate limit, false otherwise.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |